# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envp.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='envp.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nenvp.proto\"\x15\n\x05Namep\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"\xdc\x01\n\x05Infop\x12\x1e\n\x16observation_space_type\x18\x01 \x01(\t\x12\x19\n\x11observation_shape\x18\x02 \x03(\x05\x12\x1d\n\x15observation_space_low\x18\x03 \x03(\x02\x12\x1e\n\x16observation_space_high\x18\x04 \x03(\x02\x12\x13\n\x0bnum_actions\x18\x05 \x01(\x05\x12\x19\n\x11max_episode_steps\x18\x06 \x01(\x05\x12\x19\n\x11\x61\x63tion_space_type\x18\x07 \x01(\t\x12\x0e\n\x06\x65nv_id\x18\x08 \x01(\t\"\x08\n\x06\x45mptyp\"+\n\x0cObservationp\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x02\x12\r\n\x05shape\x18\x02 \x03(\x05\"+\n\rObservationsp\x12\x1a\n\x03obs\x18\x01 \x03(\x0b\x32\r.Observationp\"(\n\x08\x41\x63tionsp\x12\x0e\n\x06\x65nv_id\x18\x01 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x05\"\x17\n\x07\x45nvIDsp\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"T\n\x0bTransitionp\x12\'\n\x10next_observation\x18\x01 \x01(\x0b\x32\r.Observationp\x12\x0e\n\x06reward\x18\x02 \x01(\x02\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\"+\n\x0cTransitionsp\x12\x1b\n\x05trans\x18\x01 \x03(\x0b\x32\x0c.Transitionp\",\n\x0cRenderModesp\x12\x0e\n\x06\x65nv_id\x18\x01 \x03(\t\x12\x0c\n\x04mode\x18\x02 \x03(\t\"3\n\x0bRenderOutsp\x12\x16\n\x03rgb\x18\x01 \x03(\x0b\x32\t.RGBArryp\x12\x0c\n\x04\x61nsi\x18\x02 \x03(\t\"\x18\n\x08RGBArryp\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\")\n\tEnvSeedsp\x12\x0e\n\x06\x65nv_id\x18\x01 \x03(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x03(\x05\x32\xf6\x01\n\x04\x45nvp\x12\x19\n\x05Makep\x12\x06.Namep\x1a\x06.Infop\"\x00\x12$\n\x06Resetp\x12\x08.EnvIDsp\x1a\x0e.Observationsp\"\x00\x12(\n\x07Renderp\x12\r.RenderModesp\x1a\x0c.RenderOutsp\"\x00\x12\x1e\n\x05Seedp\x12\n.EnvSeedsp\x1a\x07.Emptyp\"\x00\x12#\n\x05Stepp\x12\t.Actionsp\x1a\r.Transitionsp\"\x00\x12\x1f\n\x07Samplep\x12\x07.Emptyp\x1a\t.Actionsp\"\x00\x12\x1d\n\x06\x43losep\x12\x08.EnvIDsp\x1a\x07.Emptyp\"\x00\x62\x06proto3'
)




_NAMEP = _descriptor.Descriptor(
  name='Namep',
  full_name='Namep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Namep.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14,
  serialized_end=35,
)


_INFOP = _descriptor.Descriptor(
  name='Infop',
  full_name='Infop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observation_space_type', full_name='Infop.observation_space_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observation_shape', full_name='Infop.observation_shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observation_space_low', full_name='Infop.observation_space_low', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observation_space_high', full_name='Infop.observation_space_high', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_actions', full_name='Infop.num_actions', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_episode_steps', full_name='Infop.max_episode_steps', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_space_type', full_name='Infop.action_space_type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_id', full_name='Infop.env_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=258,
)


_EMPTYP = _descriptor.Descriptor(
  name='Emptyp',
  full_name='Emptyp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=268,
)


_OBSERVATIONP = _descriptor.Descriptor(
  name='Observationp',
  full_name='Observationp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Observationp.data', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='Observationp.shape', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=313,
)


_OBSERVATIONSP = _descriptor.Descriptor(
  name='Observationsp',
  full_name='Observationsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='obs', full_name='Observationsp.obs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=315,
  serialized_end=358,
)


_ACTIONSP = _descriptor.Descriptor(
  name='Actionsp',
  full_name='Actionsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_id', full_name='Actionsp.env_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='Actionsp.data', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=360,
  serialized_end=400,
)


_ENVIDSP = _descriptor.Descriptor(
  name='EnvIDsp',
  full_name='EnvIDsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='EnvIDsp.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=425,
)


_TRANSITIONP = _descriptor.Descriptor(
  name='Transitionp',
  full_name='Transitionp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_observation', full_name='Transitionp.next_observation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reward', full_name='Transitionp.reward', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='done', full_name='Transitionp.done', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=427,
  serialized_end=511,
)


_TRANSITIONSP = _descriptor.Descriptor(
  name='Transitionsp',
  full_name='Transitionsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trans', full_name='Transitionsp.trans', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=556,
)


_RENDERMODESP = _descriptor.Descriptor(
  name='RenderModesp',
  full_name='RenderModesp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_id', full_name='RenderModesp.env_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='RenderModesp.mode', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=602,
)


_RENDEROUTSP = _descriptor.Descriptor(
  name='RenderOutsp',
  full_name='RenderOutsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rgb', full_name='RenderOutsp.rgb', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ansi', full_name='RenderOutsp.ansi', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=604,
  serialized_end=655,
)


_RGBARRYP = _descriptor.Descriptor(
  name='RGBArryp',
  full_name='RGBArryp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='RGBArryp.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=657,
  serialized_end=681,
)


_ENVSEEDSP = _descriptor.Descriptor(
  name='EnvSeedsp',
  full_name='EnvSeedsp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='env_id', full_name='EnvSeedsp.env_id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='EnvSeedsp.data', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=724,
)

_OBSERVATIONSP.fields_by_name['obs'].message_type = _OBSERVATIONP
_TRANSITIONP.fields_by_name['next_observation'].message_type = _OBSERVATIONP
_TRANSITIONSP.fields_by_name['trans'].message_type = _TRANSITIONP
_RENDEROUTSP.fields_by_name['rgb'].message_type = _RGBARRYP
DESCRIPTOR.message_types_by_name['Namep'] = _NAMEP
DESCRIPTOR.message_types_by_name['Infop'] = _INFOP
DESCRIPTOR.message_types_by_name['Emptyp'] = _EMPTYP
DESCRIPTOR.message_types_by_name['Observationp'] = _OBSERVATIONP
DESCRIPTOR.message_types_by_name['Observationsp'] = _OBSERVATIONSP
DESCRIPTOR.message_types_by_name['Actionsp'] = _ACTIONSP
DESCRIPTOR.message_types_by_name['EnvIDsp'] = _ENVIDSP
DESCRIPTOR.message_types_by_name['Transitionp'] = _TRANSITIONP
DESCRIPTOR.message_types_by_name['Transitionsp'] = _TRANSITIONSP
DESCRIPTOR.message_types_by_name['RenderModesp'] = _RENDERMODESP
DESCRIPTOR.message_types_by_name['RenderOutsp'] = _RENDEROUTSP
DESCRIPTOR.message_types_by_name['RGBArryp'] = _RGBARRYP
DESCRIPTOR.message_types_by_name['EnvSeedsp'] = _ENVSEEDSP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Namep = _reflection.GeneratedProtocolMessageType('Namep', (_message.Message,), {
  'DESCRIPTOR' : _NAMEP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Namep)
  })
_sym_db.RegisterMessage(Namep)

Infop = _reflection.GeneratedProtocolMessageType('Infop', (_message.Message,), {
  'DESCRIPTOR' : _INFOP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Infop)
  })
_sym_db.RegisterMessage(Infop)

Emptyp = _reflection.GeneratedProtocolMessageType('Emptyp', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Emptyp)
  })
_sym_db.RegisterMessage(Emptyp)

Observationp = _reflection.GeneratedProtocolMessageType('Observationp', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Observationp)
  })
_sym_db.RegisterMessage(Observationp)

Observationsp = _reflection.GeneratedProtocolMessageType('Observationsp', (_message.Message,), {
  'DESCRIPTOR' : _OBSERVATIONSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Observationsp)
  })
_sym_db.RegisterMessage(Observationsp)

Actionsp = _reflection.GeneratedProtocolMessageType('Actionsp', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Actionsp)
  })
_sym_db.RegisterMessage(Actionsp)

EnvIDsp = _reflection.GeneratedProtocolMessageType('EnvIDsp', (_message.Message,), {
  'DESCRIPTOR' : _ENVIDSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:EnvIDsp)
  })
_sym_db.RegisterMessage(EnvIDsp)

Transitionp = _reflection.GeneratedProtocolMessageType('Transitionp', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Transitionp)
  })
_sym_db.RegisterMessage(Transitionp)

Transitionsp = _reflection.GeneratedProtocolMessageType('Transitionsp', (_message.Message,), {
  'DESCRIPTOR' : _TRANSITIONSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:Transitionsp)
  })
_sym_db.RegisterMessage(Transitionsp)

RenderModesp = _reflection.GeneratedProtocolMessageType('RenderModesp', (_message.Message,), {
  'DESCRIPTOR' : _RENDERMODESP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:RenderModesp)
  })
_sym_db.RegisterMessage(RenderModesp)

RenderOutsp = _reflection.GeneratedProtocolMessageType('RenderOutsp', (_message.Message,), {
  'DESCRIPTOR' : _RENDEROUTSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:RenderOutsp)
  })
_sym_db.RegisterMessage(RenderOutsp)

RGBArryp = _reflection.GeneratedProtocolMessageType('RGBArryp', (_message.Message,), {
  'DESCRIPTOR' : _RGBARRYP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:RGBArryp)
  })
_sym_db.RegisterMessage(RGBArryp)

EnvSeedsp = _reflection.GeneratedProtocolMessageType('EnvSeedsp', (_message.Message,), {
  'DESCRIPTOR' : _ENVSEEDSP,
  '__module__' : 'envp_pb2'
  # @@protoc_insertion_point(class_scope:EnvSeedsp)
  })
_sym_db.RegisterMessage(EnvSeedsp)



_ENVP = _descriptor.ServiceDescriptor(
  name='Envp',
  full_name='Envp',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=727,
  serialized_end=973,
  methods=[
  _descriptor.MethodDescriptor(
    name='Makep',
    full_name='Envp.Makep',
    index=0,
    containing_service=None,
    input_type=_NAMEP,
    output_type=_INFOP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Resetp',
    full_name='Envp.Resetp',
    index=1,
    containing_service=None,
    input_type=_ENVIDSP,
    output_type=_OBSERVATIONSP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Renderp',
    full_name='Envp.Renderp',
    index=2,
    containing_service=None,
    input_type=_RENDERMODESP,
    output_type=_RENDEROUTSP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Seedp',
    full_name='Envp.Seedp',
    index=3,
    containing_service=None,
    input_type=_ENVSEEDSP,
    output_type=_EMPTYP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stepp',
    full_name='Envp.Stepp',
    index=4,
    containing_service=None,
    input_type=_ACTIONSP,
    output_type=_TRANSITIONSP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Samplep',
    full_name='Envp.Samplep',
    index=5,
    containing_service=None,
    input_type=_EMPTYP,
    output_type=_ACTIONSP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Closep',
    full_name='Envp.Closep',
    index=6,
    containing_service=None,
    input_type=_ENVIDSP,
    output_type=_EMPTYP,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ENVP)

DESCRIPTOR.services_by_name['Envp'] = _ENVP

# @@protoc_insertion_point(module_scope)
